package # Hide from PAUSE
    Date::Holidays::Adapter::CA_ES;

use strict;
use warnings;

our $VERSION = '0.01';

use base 'Date::Holidays::Adapter::ES';

1;
__END__

=head1 NAME

Date::Holidays::Adapter::CA_ES - An adapter class for Date::Holidays::CA_ES

=head1 DESCRIPTION

Just a subclass of Date::Holidays::Adapter::ES.

=head1 AUTHOR

Miquel Ruiz, E<lt>mruiz@cpan.orgE<gt>

=head1 COPYRIGHT & LICENSE

Copyright Miquel Ruiz 2010

This program is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
